==> pollen-ui-struts2-1.3.1.1-sources.jar: org/chorem/pollen/ui/actions/poll/ConfirmDeleteChoice.java <==
/*
 * #%L
 * Pollen :: UI (strust2)
 * 
 * $Id: ConfirmDeleteChoice.java 3394 2012-05-28 15:27:04Z tchemit $
 * $HeadURL: http://svn.chorem.org/svn/pollen/tags/pollen-1.3.1.1/pollen-ui-struts2/src/main/java/org/chorem/pollen/ui/actions/poll/ConfirmDeleteChoice.java $
 * %%
 * Copyright (C) 2009 - 2012 CodeLutin, Tony Chemit
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.pollen.ui.actions.poll;

import com.google.common.base.Preconditions;
import org.chorem.pollen.business.persistence.Choice;
import org.chorem.pollen.business.persistence.Poll;
import org.chorem.pollen.services.impl.PollService;

/**
 * To confirm delete of a poll choice.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.3
 */
public class ConfirmDeleteChoice extends AbstractPollUriIdAction {

    private static final long serialVersionUID = 1L;

    protected String choiceId;

    protected Choice choice;

    public void setChoiceId(String choiceId) {
        this.choiceId = choiceId;
    }

    public Choice getChoice() {
        return choice;
    }

    @Override
    public String execute() throws Exception {

        String pollId = getPollId();
        Preconditions.checkNotNull(pollId);
        Preconditions.checkNotNull(choiceId);

        PollService service = newService(PollService.class);

        Poll poll = service.getPollByPollId(pollId);

        choice = poll.getChoiceByTopiaId(choiceId);

        return SUCCESS;
    }
}

==> pollen-ui-struts2-1.4-sources.jar: org/chorem/pollen/ui/actions/poll/ConfirmDeleteChoice.java <==
/*
 * #%L
 * Pollen :: UI (struts2)
 * $Id: ConfirmDeleteChoice.java 3423 2012-06-05 16:50:22Z tchemit $
 * $HeadURL: http://svn.chorem.org/svn/pollen/tags/pollen-1.4/pollen-ui-struts2/src/main/java/org/chorem/pollen/ui/actions/poll/ConfirmDeleteChoice.java $
 * %%
 * Copyright (C) 2009 - 2012 CodeLutin, Tony Chemit
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.pollen.ui.actions.poll;

import com.google.common.base.Preconditions;
import org.chorem.pollen.business.persistence.Choice;
import org.chorem.pollen.business.persistence.Poll;

/**
 * To confirm delete of a poll choice.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.3
 */
public class ConfirmDeleteChoice extends AbstractPollUriIdAction {

    private static final long serialVersionUID = 1L;

    protected String choiceId;

    protected Choice choice;

    public void setChoiceId(String choiceId) {
        this.choiceId = choiceId;
    }

    public Choice getChoice() {
        return choice;
    }

    @Override
    public String execute() throws Exception {

        String pollId = getPollId();
        Preconditions.checkNotNull(pollId);
        Preconditions.checkNotNull(choiceId);

        Poll poll = getPollService().getExistingPollByPollId(pollId);

        choice = poll.getChoiceByTopiaId(choiceId);

        return SUCCESS;
    }
}
